Profiling
----------------------

.. currentmodule:: flax.linen

.. autofunction:: enable_named_call
.. autofunction:: disable_named_call
.. autofunction:: override_named_call

**Summary**

.. autosummary::
  :toctree: _autosummary

  enable_named_call
  disable_named_call
  override_named_call